%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

# Golang minor version
%if 0%{?rhel} && ! 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif

%global provider github
%global provider_tld com
%global project cri-o
%global repo cri-o
# https://github.com/cri-o/cri-o
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global commit0 9575c69786a7c101e31e2a109253b1262df0269c
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global git0 https://%{import_path}

%global service_name crio

Name: %{repo}
Version: 1.19.2
Release: 2.rhaos4.6.git%{shortcommit0}%{?dist}
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1: seccomp.json
Source3: %{service_name}-network.sysconfig
Source4: %{service_name}-storage.sysconfig
Source5: %{service_name}-metrics.sysconfig
Source6: %{service_name}.service
BuildRequires: golang
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: pkgconfig(systemd)
Requires(pre): container-selinux
Requires: skopeo-containers >= 1:0.1.40-1
Requires: runc >= 1.0.0-61.rc8
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Requires: containernetworking-plugins >= 0.8.2-3
Requires: conmon >= 2.0.2-2

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
cp %{SOURCE6} contrib/systemd/.
sed -i 's/\.gopathok //' Makefile
sed -i 's/%{version}/%{version}-%{release}/' internal/version/version.go
sed -i 's/\/local//' contrib/systemd/%{service_name}.service
sed -i 's/\/local//' contrib/systemd/%{service_name}-wipe.service

%build
mkdir _output
pushd _output
mkdir -p src/%{provider}.%{provider_tld}/{%{project},opencontainers}
ln -s $(dirs +1 -l) src/%{import_path}
popd

ln -s vendor src
export GOPATH=$(pwd)/_output:$(pwd)
export BUILDTAGS="selinux seccomp exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_ostree_stub"
export GO111MODULE=off
# https://bugzilla.redhat.com/show_bug.cgi?id=1825623
export VERSION=%{version}
# build crio
%gobuild -o bin/%{service_name} %{import_path}/cmd/%{service_name}

# build crio-status
%gobuild -o bin/crio-status %{import_path}/cmd/crio-status

# build pinns and docs
%{__make} bin/pinns
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
GO_MD2MAN=go-md2man GO="scl enable go-toolset-1.13 -- go" %{__make} docs
%else
GO_MD2MAN=go-md2man %{__make} docs
%endif

%install
./bin/%{service_name} \
      --selinux \
      --cgroup-manager "systemd" \
      --storage-driver "overlay" \
      --conmon "%{_libexecdir}/crio/conmon" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --storage-opt "overlay.override_kernel_check=1" \
      config > %{service_name}.conf

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf

install -dp %{buildroot}%{_sysconfdir}/sysconfig
#install -p -m 644 contrib/sysconfig/%%{service_name} %%{buildroot}%%{_sysconfdir}/sysconfig/%%{service_name}
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-network
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-storage
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-metrics

make PREFIX=%{buildroot}%{_prefix} DESTDIR=%{buildroot} \
            install.bin-nobuild \
            install.completions \
            install.config-nobuild \
            install.man-nobuild \
            install.systemd

# install seccomp.json
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{service_name}/seccomp.json

install -dp %{buildroot}%{_sharedstatedir}/containers
install -dp %{buildroot}%{_sharedstatedir}/cni/bin
install -dp %{buildroot}%{_sysconfdir}/kubernetes/cni/net.d
install -dp %{buildroot}%{_datadir}/containers/oci/hooks.d
install -dp %{buildroot}/opt/cni/bin

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/%{service_name}-status
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}.conf*5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/%{service_name}/seccomp.json
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-storage
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-network
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-metrics
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml
%{_unitdir}/%{service_name}.service
%{_unitdir}/%{name}.service
%{_unitdir}/%{service_name}-shutdown.service
%{_unitdir}/%{service_name}-wipe.service
%dir %{_sharedstatedir}/containers
%dir %{_sharedstatedir}/cni
%dir %{_sharedstatedir}/cni/bin
%dir %{_sysconfdir}/kubernetes
%dir %{_sysconfdir}/kubernetes/cni
%dir %{_sysconfdir}/kubernetes/cni/net.d
%dir %{_datadir}/containers
%dir %{_datadir}/containers/oci
%dir %{_datadir}/containers/oci/hooks.d
%dir /opt/cni
%dir /opt/cni/bin
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%{_datadir}/bash-completion/completions/%{service_name}*
%{_datadir}/fish/completions/%{service_name}*.fish
%{_datadir}/zsh/site-functions/_%{service_name}*

%changelog
* Thu Jun 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.2-2.rhaos4.6.git9575c69
- bump to 1.19.2
- autobuilt 9575c69

* Wed May 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-16.rhaos4.6.git130633b
- autobuilt 130633b

* Fri Apr 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-15.rhaos4.6.git90e397e
- autobuilt 90e397e

* Wed Apr 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-14.rhaos4.6.gita83ffa9
- autobuilt a83ffa9

* Tue Apr 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-13.rhaos4.6.gitc83c8cc
- autobuilt c83c8cc

* Tue Apr 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-12.rhaos4.6.git483f47a
- autobuilt 483f47a

* Tue Mar 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-11.rhaos4.6.git050df4c
- autobuilt 050df4c

* Thu Mar 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-10.rhaos4.6.git27e71a0
- autobuilt 27e71a0

* Thu Mar 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-9.rhaos4.6.gitdfec2c4
- autobuilt dfec2c4

* Fri Feb 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-8.rhaos4.6.gitc90bfb8
- autobuilt c90bfb8

* Tue Jan 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-7.rhaos4.6.git6377f68
- autobuilt 6377f68

* Wed Jan 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-6.rhaos4.6.git6de578b
- autobuilt 6de578b

* Wed Jan 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-5.rhaos4.6.git4b82b5f
- autobuilt 4b82b5f

* Mon Jan 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-4.rhaos4.6.git3846aab
- autobuilt 3846aab

* Fri Jan 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-3.rhaos4.6.gitc9c3658
- autobuilt c9c3658

* Thu Dec 24 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.1-2.rhaos4.6.git2af9ecf
- bump to 1.19.1
- autobuilt 2af9ecf

* Thu Dec 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-26.rhaos4.6.git8a05a29
- autobuilt 8a05a29

* Tue Nov 17 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-25.rhaos4.6.gitf51f94a
- autobuilt f51f94a

* Tue Nov 10 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-24.rhaos4.6.git571103d
- autobuilt 571103d

* Mon Nov 09 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-23.rhaos4.6.git9df9da5
- autobuilt 9df9da5

* Tue Oct 20 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-22.rhaos4.6.gitc0306f1
- autobuilt c0306f1

* Wed Oct 14 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-21.rhaos4.6.git4372f43
- autobuilt 4372f43

* Thu Oct 01 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-20.rhaos4.6.git97d715e
- autobuilt 97d715e

* Wed Sep 30 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-19.rhaos4.6.gitda1d894
- autobuilt da1d894

* Wed Sep 16 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-18.rhaos4.6.gitd802e19
- autobuilt d802e19

* Mon Sep 14 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-17.rhaos4.6.git99c925b
- autobuilt 99c925b

* Sat Sep 12 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-16.rhaos4.6.git1852363
- autobuilt 1852363

* Sat Sep 12 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-15.rhaos4.6.git55a2b1c
- autobuilt 55a2b1c

* Sat Sep 12 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-14.rhaos4.6.git78d4154
- autobuilt 78d4154

* Fri Sep 11 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-13.rhaos4.6.gite4e2f78
- autobuilt e4e2f78

* Fri Sep 11 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-12.rhaos4.6.git98e356c
- autobuilt 98e356c

* Tue Sep 08 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-11.rhaos4.6.gitf83564f
- autobuilt f83564f

* Tue Sep 08 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-10.rhaos4.6.git1707a31
- autobuilt 1707a31

* Mon Sep 07 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-9.rhaos4.6.gitc70e6c8
- autobuilt c70e6c8

* Fri Sep 04 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-8.rhaos4.6.git488942f
- autobuilt 488942f

* Fri Sep 04 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-7.rhaos4.6.git77ab933
- autobuilt 77ab933

* Fri Sep 04 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-6.rhaos4.6.gita3f3cb9
- autobuilt a3f3cb9

* Thu Sep 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-5.rhaos4.6.gite916d4f
- autobuilt e916d4f

* Thu Sep 03 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-4.rhaos4.6.git3b3ba76
- autobuilt 3b3ba76

* Mon Aug 31 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-3.rhaos4.6.gitfb31986
- autobuilt fb31986

* Sun Aug 30 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-2.rhaos4.6.gitac7f451
- bump to 1.19.0
- autobuilt ac7f451

* Sun Aug 30 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com>
- bump to 1.15.1
- autobuilt 

* Fri Aug 28 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-95.rhaos4.6.gitac7f451
- autobuilt ac7f451

* Thu Aug 27 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-94.rhaos4.6.git462ad71
- autobuilt 462ad71

* Thu Aug 27 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-93.rhaos4.6.gitac7f451
- autobuilt ac7f451

* Thu Aug 27 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-92.rhaos4.6.gitfc125d6
- autobuilt fc125d6

* Wed Aug 26 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.19.0-91.rhaos4.6.gitb7b07b7
- autobuilt b7b07b7

* Tue Aug 25 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-90.rhaos4.6.git4a0ac05
- autobuilt 4a0ac05

* Tue Aug 25 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-89.rhaos4.6.git7382e45
- autobuilt 7382e45

* Sun Aug 23 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-88.rhaos4.6.gitac7f451
- autobuilt ac7f451

* Thu Aug 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-87.rhaos4.6.git5f02fa2
- autobuilt 5f02fa2

* Thu Aug 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-86.rhaos4.6.git56f7938
- autobuilt 56f7938

* Thu Aug 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-85.rhaos4.6.git6efed8b
- autobuilt 6efed8b

* Wed Aug 19 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-84.rhaos4.6.git73f7f7b
- autobuilt 73f7f7b

* Wed Aug 19 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-83.rhaos4.6.git745551f
- autobuilt 745551f

* Tue Aug 18 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-82.rhaos4.6.git743c01a
- autobuilt 743c01a

* Tue Aug 18 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-81.rhaos4.6.gitfe43b78
- autobuilt fe43b78

* Mon Aug 17 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-80.rhaos4.6.gitd5e328b
- autobuilt d5e328b

* Mon Aug 17 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-79.rhaos4.6.gitab21cff
- autobuilt ab21cff

* Mon Aug 17 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-78.rhaos4.6.git24d947e
- autobuilt 24d947e

* Thu Aug 13 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-77.rhaos4.6.git15ca456
- autobuilt 15ca456

* Thu Aug 13 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-76.rhaos4.6.gitd8dd383
- autobuilt d8dd383

* Thu Aug 13 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-75.rhaos4.6.git92c13a9
- autobuilt 92c13a9

* Wed Aug 12 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-74.rhaos4.6.gitcf0ca90
- autobuilt cf0ca90

* Tue Aug 11 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-73.rhaos4.6.gitd00b217
- autobuilt d00b217

* Tue Aug 11 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-72.rhaos4.6.git45c387d
- autobuilt 45c387d

* Mon Aug 10 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-71.rhaos4.6.git19455e9
- autobuilt 19455e9

* Mon Aug 10 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-70.rhaos4.6.git66c5b77
- autobuilt 66c5b77

* Fri Aug 07 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-69.rhaos4.6.git707b4b9
- autobuilt 707b4b9

* Thu Aug 06 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-68.rhaos4.6.git8591514
- autobuilt 8591514

* Wed Aug 05 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-67.rhaos4.6.gitc964c31
- autobuilt c964c31

* Wed Aug 05 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-66.rhaos4.6.git47d757a
- autobuilt 47d757a

* Tue Aug 04 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-65.rhaos4.6.gitdaba997
- autobuilt daba997

* Tue Aug 04 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-64.rhaos4.6.gitee12363
- autobuilt ee12363

* Tue Aug 04 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-63.rhaos4.6.git2292b29
- autobuilt 2292b29

* Mon Aug 03 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-62.rhaos4.6.git10c7a86
- autobuilt 10c7a86

* Sun Aug 02 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-61.rhaos4.6.git79c1228
- autobuilt 79c1228

* Sat Aug 01 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-60.rhaos4.6.gitdc94c19
- autobuilt dc94c19

* Sat Aug 01 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-59.rhaos4.6.git1ffc93a
- autobuilt 1ffc93a

* Fri Jul 31 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-58.rhaos4.6.gitc5101e9
- autobuilt c5101e9

* Thu Jul 30 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-57.rhaos4.6.git11717b5
- autobuilt 11717b5

* Thu Jul 30 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-56.rhaos4.6.git63dd302
- autobuilt 63dd302

* Thu Jul 30 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-55.rhaos4.6.gita0ab3df
- autobuilt a0ab3df

* Thu Jul 30 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-54.rhaos4.6.git5d0b286
- autobuilt 5d0b286

* Wed Jul 29 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-53.rhaos4.6.git1f9d304
- autobuilt 1f9d304

* Wed Jul 29 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-52.rhaos4.6.git44e69bf
- autobuilt 44e69bf

* Tue Jul 28 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-51.rhaos4.6.git5f6595c
- autobuilt 5f6595c

* Fri Jul 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-50.rhaos4.6.git6468327
- autobuilt 6468327

* Fri Jul 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-49.rhaos4.6.git44f85cf
- autobuilt 44f85cf

* Thu Jul 23 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-48.rhaos4.6.git5c7f7e6
- autobuilt 5c7f7e6

* Thu Jul 23 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-47.rhaos4.6.gite9a6faa
- autobuilt e9a6faa

* Thu Jul 23 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-46.rhaos4.6.gitd627a25
- autobuilt d627a25

* Wed Jul 22 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-45.rhaos4.6.gitb8e64d3
- autobuilt b8e64d3

* Wed Jul 22 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-44.rhaos4.6.gitbf97cfd
- autobuilt bf97cfd

* Wed Jul 22 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-43.rhaos4.6.gitf332045
- autobuilt f332045

* Wed Jul 22 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-42.rhaos4.6.git4eda10c
- autobuilt 4eda10c

* Tue Jul 21 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-41.rhaos4.6.git988f60e
- autobuilt 988f60e

* Tue Jul 21 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-40.rhaos4.6.git0fdee7a
- autobuilt 0fdee7a

* Tue Jul 21 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-39.rhaos4.6.git8cc5808
- autobuilt 8cc5808

* Mon Jul 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-38.rhaos4.6.git336ef5f
- autobuilt 336ef5f

* Mon Jul 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-37.rhaos4.6.git27c8c89
- autobuilt 27c8c89

* Mon Jul 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-36.rhaos4.6.git2ac1fb1
- autobuilt 2ac1fb1

* Mon Jul 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-35.rhaos4.6.git0d9584c
- autobuilt 0d9584c

* Fri Jul 17 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-34.rhaos4.6.git9abd56f
- autobuilt 9abd56f

* Fri Jul 17 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-33.rhaos4.6.git8adc682
- autobuilt 8adc682

* Thu Jul 16 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-32.rhaos4.6.gitd142625
- autobuilt d142625

* Mon Jul 06 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.19.0-31.rhaos4.6.git0a84af5
- bump release tag

* Thu Jul 02 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-2.rhaos4.6.git0a84af5
- bump to 1.19.0
- autobuilt 0a84af5

* Thu Jul 02 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-2.rhaos4.6.git0a84af5
- bump to 1.19.0
- autobuilt 0a84af5

* Sat Jun 27 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-2.rhaos4.6.git0a84af5
- bump to 1.19.0
- autobuilt 0a84af5

* Thu Jun 25 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-30.dev.rhaos4.6.git0a84af5
- autobuilt 0a84af5

* Wed Jun 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-29.dev.rhaos4.6.git67805d4
- autobuilt 67805d4

* Wed Jun 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-28.dev.rhaos4.6.git55e534e
- autobuilt 55e534e

* Tue Jun 23 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-27.dev.rhaos4.6.git1c60865
- autobuilt 1c60865

* Mon Jun 22 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-26.dev.rhaos4.6.git44d065f
- autobuilt 44d065f

* Mon Jun 22 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-25.dev.rhaos4.6.git5f4fa29
- autobuilt 5f4fa29

* Sat Jun 20 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-24.dev.rhaos4.6.gitdefae7b
- autobuilt defae7b

* Fri Jun 19 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-23.dev.rhaos4.6.git6902246
- autobuilt 6902246

* Wed Jun 17 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-22.dev.rhaos4.6.gitb77034b
- autobuilt b77034b

* Mon Jun 15 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-21.dev.rhaos4.6.gite22db0a
- autobuilt e22db0a

* Mon Jun 15 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-20.dev.rhaos4.6.git2ab1b94
- autobuilt 2ab1b94

* Wed Jun 10 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af59.dev.rhaos4.6.git3f327dc
- autobuilt 3f327dc

* Wed Jun 10 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af58.dev.rhaos4.6.gitfa6ccf3
- autobuilt fa6ccf3

* Tue Jun 09 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af57.dev.rhaos4.6.git71878bc
- autobuilt 71878bc

* Tue Jun 09 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af56.dev.rhaos4.6.gitb2493a6
- autobuilt b2493a6

* Tue Jun 09 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af55.dev.rhaos4.6.gitc6d7943
- autobuilt c6d7943

* Tue Jun 09 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af54.dev.rhaos4.6.git375d335
- autobuilt 375d335

* Mon Jun 08 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af53.dev.rhaos4.6.git2091ba4
- autobuilt 2091ba4

* Mon Jun 08 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af52.dev.rhaos4.6.gitaa2551d
- autobuilt aa2551d

* Mon Jun 08 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af51.dev.rhaos4.6.gitddc86a7
- autobuilt ddc86a7

* Sun Jun 07 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af50.dev.rhaos4.6.git316a038
- autobuilt 316a038

* Fri Jun 05 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-9.dev.rhaos4.6.gitab9a0e5
- autobuilt ab9a0e5

* Fri Jun 05 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-8.dev.rhaos4.6.git3804750
- autobuilt 3804750

* Fri Jun 05 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-7.dev.rhaos4.6.gitecf8785
- autobuilt ecf8785

* Thu Jun 04 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-6.dev.rhaos4.6.gitd5a93ad
- autobuilt d5a93ad

* Thu Jun 04 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-5.dev.rhaos4.6.gite5ce0a5
- autobuilt e5ce0a5

* Tue Jun 02 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-4.dev.rhaos4.6.git8b8a3a0
- autobuilt 8b8a3a0

* Tue Jun 02 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-3.dev.rhaos4.6.gite4995ca
- autobuilt e4995ca

* Wed May 27 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.19.0-2.dev.rhaos4.6.gitad83d2a
- autobuilt ad83d2a

* Tue May 19 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.19.0-1.rhaos4.6.gitac7f451.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.rhaos4.6.git0a84af5.dev.rhaos4.6.git13fadc1
- built release-1.19

* Tue Apr 28 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.18.0-10.dev.rhaos4.5.gite1dd11d
- autobuilt e1dd11d

* Tue Apr 28 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.18.0-9.dev.rhaos4.5.gite351f97
- autobuilt e351f97

* Mon Apr 27 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.18.0-8.dev.rhaos4.5.gitd62a179
- autobuilt d62a179

* Sat Apr 25 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.18.0-7.dev.rhaos4.5.gitb92e242
- autobuilt b92e242

* Sat Apr 25 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.18.0-6.dev.rhaos4.5.giteccf06d
- autobuilt eccf06d

* Fri Apr 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.18.0-5.dev.rhaos4.5.git7da4850
- autobuilt 7da4850

* Fri Apr 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.18.0-4.dev.rhaos4.5.git7d79f42
- autobuilt 7d79f42

* Mon Apr 20 2020 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.18.0-3.dev.rhaos4.5.git2cef6c3
- built 2cef6c3

* Sun Apr 19 2020 Colin Walters <walters@verbum.org> - 1.18.0-2.rhaos4.5
- Export version from RPM spec

* Fri Apr 17 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.18.0-1.rhaos4.5
- bump to v1.18.0-rc1

* Mon Apr 13 2020 Jindrich Novy <jnovy@redhat.com> - 1.17.3-1.rhaos4.5
- update to https://github.com/cri-o/cri-o/releases/tag/v1.17.3
- simplify package NVR and delivery
- Resolves: #1821511

* Wed Apr 01 2020 Jindrich Novy <jnovy@redhat.com> - 1.17.0-10.dev.rhaos4.5.gitdfc8414
- initial build for rhaos4.5
